# CLI client for Vikunja

> [The todo app to organize your life.](https://vikunja.io/)

This is a simple command line client for Vikunja, written in python.

## Installation
- Copy folder .vjacli to your Home directory and adjust to your needs.
- Install from pypi
```shell
pip install vja
vja --help
```

## Usage

## Project setup
```shell
rm -rf build dist vja.egg-info; python setup.py sdist bdist_wheel; pip install .
```

### Compiles and hot-reloads for development

```shell
pip uninstall -y vja;rm -rf build dist vja.egg-info; python setup.py sdist bdist_wheel; pip install .
twine upload dist/*
pip install vja -U
vja ls
```

